@@ -53,12 +53,13 @@ class AddSmsSignRequest(AbstractModel):
 注：不能重复申请已通过或待审核的签名。
         :type SignName: str
         :param SignType: 签名类型。其中每种类型后面标注了其可选的 DocumentType（证明类型）：
-0：公司，可选 DocumentType 有（0，1，2，3）。
+0：公司，可选 DocumentType 有（0，1）。
 1：APP，可选 DocumentType 有（0，1，2，3，4） 。
 2：网站，可选 DocumentType 有（0，1，2，3，5）。
-3：公众号或者小程序，可选 DocumentType 有（0，1，2，3，6）。
+3：公众号，可选 DocumentType 有（0，1，2，3，8）。
 4：商标，可选 DocumentType 有（7）。
 5：政府/机关事业单位/其他机构，可选 DocumentType 有（2，3）。
+6：小程序，可选 DocumentType 有（0，1，2，3，6）。
 注：必须按照对应关系选择证明类型，否则会审核失败。
         :type SignType: int
         :param DocumentType: 证明类型：
@@ -70,7 +71,7 @@ class AddSmsSignRequest(AbstractModel):
 5：网站备案后台截图（个人开发网站）。
 6：小程序设置页面截图（个人认证小程序）。
 7：商标注册书。
-注：必选按照 SignType 选择对应的DocumentType。
+8：公众号设置页面截图（个人认证公众号）。
         :type DocumentType: int
         :param International: 是否国际/港澳台短信：
 0：表示国内短信。
@@ -501,6 +502,57 @@ class DeleteTemplateStatus(AbstractModel):
         
 
 
+class DescribePhoneNumberInfoRequest(AbstractModel):
+    """DescribePhoneNumberInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PhoneNumberSet: 查询手机号码，采用 E.164 标准，格式为+[国家或地区码][手机号]，单次请求最多支持200个手机号。
+例如：+8613711112222， 其中前面有一个+号 ，86为国家码，13711112222为手机号。
+        :type PhoneNumberSet: list of str
+        """
+        self.PhoneNumberSet = None
+
+
+    def _deserialize(self, params):
+        self.PhoneNumberSet = params.get("PhoneNumberSet")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribePhoneNumberInfoResponse(AbstractModel):
+    """DescribePhoneNumberInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PhoneNumberInfoSet: 获取号码信息。
+        :type PhoneNumberInfoSet: list of PhoneNumberInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.PhoneNumberInfoSet = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("PhoneNumberInfoSet") is not None:
+            self.PhoneNumberInfoSet = []
+            for item in params.get("PhoneNumberInfoSet"):
+                obj = PhoneNumberInfo()
+                obj._deserialize(item)
+                self.PhoneNumberInfoSet.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeSignListStatus(AbstractModel):
     """获取短信签名信息响应
 
@@ -610,21 +662,31 @@ class DescribeSmsTemplateListRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param TemplateIdSet: 模板 ID 数组。
-<dx-alert infotype="notice" title="注意">默认数组长度最大100</dx-alert>
-        :type TemplateIdSet: list of int non-negative
         :param International: 是否国际/港澳台短信：
 0：表示国内短信。
 1：表示国际/港澳台短信。
         :type International: int
+        :param TemplateIdSet: 模板 ID 数组。数组为空时默认查询模板列表信息（仅允许主账号使用），请使用 Limit 和 Offset 字段设置查询范围。
+<dx-alert infotype="notice" title="注意">默认数组长度最大100</dx-alert>
+        :type TemplateIdSet: list of int non-negative
+        :param Limit: 最大上限，最多100。
+注：默认为0，TemplateIdSet 为空时启用。
+        :type Limit: int
+        :param Offset: 偏移量。
+注：默认为0，TemplateIdSet 为空时启用。
+        :type Offset: int
         """
-        self.TemplateIdSet = None
         self.International = None
+        self.TemplateIdSet = None
+        self.Limit = None
+        self.Offset = None
 
 
     def _deserialize(self, params):
-        self.TemplateIdSet = params.get("TemplateIdSet")
         self.International = params.get("International")
+        self.TemplateIdSet = params.get("TemplateIdSet")
+        self.Limit = params.get("Limit")
+        self.Offset = params.get("Offset")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -744,12 +806,13 @@ class ModifySmsSignRequest(AbstractModel):
         :param SignName: 签名名称。
         :type SignName: str
         :param SignType: 签名类型。其中每种类型后面标注了其可选的 DocumentType（证明类型）：
-0：公司，可选 DocumentType 有（0，1，2，3）。
+0：公司，可选 DocumentType 有（0，1）。
 1：APP，可选 DocumentType 有（0，1，2，3，4） 。
 2：网站，可选 DocumentType 有（0，1，2，3，5）。
-3：公众号或者小程序，可选 DocumentType 有（0，1，2，3，6）。
+3：公众号，可选 DocumentType 有（0，1，2，3，8）。
 4：商标，可选 DocumentType 有（7）。
 5：政府/机关事业单位/其他机构，可选 DocumentType 有（2，3）。
+6：小程序，可选 DocumentType 有（0，1，2，3，6）。
 注：必须按照对应关系选择证明类型，否则会审核失败。
         :type SignType: int
         :param DocumentType: 证明类型：
@@ -761,7 +824,7 @@ class ModifySmsSignRequest(AbstractModel):
 5：网站备案后台截图（个人开发网站）。
 6：小程序设置页面截图（个人认证小程序）。
 7：商标注册书。
-注：必选按照 SignType 选择对应的DocumentType。
+8：公众号设置页面截图（个人认证公众号）。
         :type DocumentType: int
         :param International: 是否国际/港澳台短信：
 0：表示国内短信。
@@ -927,6 +990,54 @@ class ModifyTemplateStatus(AbstractModel):
         
 
 
+class PhoneNumberInfo(AbstractModel):
+    """号码信息。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Code: 号码信息查询错误码，查询成功返回 "Ok"。
+        :type Code: str
+        :param Message: 号码信息查询错误码描述。
+        :type Message: str
+        :param NationCode: 国家（或地区）码。
+        :type NationCode: str
+        :param SubscriberNumber: 用户号码，去除国家或地区码前缀的普通格式，示例如：13711112222。
+        :type SubscriberNumber: str
+        :param PhoneNumber: 解析后的规范的 E.164 号码，与下发短信的号码解析结果一致。解析失败时会原样返回。
+        :type PhoneNumber: str
+        :param IsoCode: 国家码或地区码，例如 CN、US 等，对于未识别出国家码或者地区码，默认返回 DEF。
+        :type IsoCode: str
+        :param IsoName: 国家码或地区名，例如 China，可参考 [国际/港澳台短信价格总览](https://cloud.tencent.com/document/product/382/18051#.E6.97.A5.E7.BB.93.E5.90.8E.E4.BB.98.E8.B4.B9.3Ca-id.3D.22post-payment.22.3E.3C.2Fa.3E)
+        :type IsoName: str
+        """
+        self.Code = None
+        self.Message = None
+        self.NationCode = None
+        self.SubscriberNumber = None
+        self.PhoneNumber = None
+        self.IsoCode = None
+        self.IsoName = None
+
+
+    def _deserialize(self, params):
+        self.Code = params.get("Code")
+        self.Message = params.get("Message")
+        self.NationCode = params.get("NationCode")
+        self.SubscriberNumber = params.get("SubscriberNumber")
+        self.PhoneNumber = params.get("PhoneNumber")
+        self.IsoCode = params.get("IsoCode")
+        self.IsoName = params.get("IsoName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class PullSmsReplyStatus(AbstractModel):
     """短信回复状态
 
@@ -1122,6 +1233,9 @@ class PullSmsSendStatus(AbstractModel):
         :type ReportStatus: str
         :param Description: 用户接收短信状态描述。
         :type Description: str
+        :param SessionContext: 用户的 session 内容。与请求中的 SessionContext 一致，默认为空，如需开通请联系 [腾讯云短信小助手](https://cloud.tencent.com/document/product/382/3773#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81)。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SessionContext: str
         """
         self.UserReceiveTime = None
         self.CountryCode = None
@@ -1130,6 +1244,7 @@ class PullSmsSendStatus(AbstractModel):
         self.SerialNo = None
         self.ReportStatus = None
         self.Description = None
+        self.SessionContext = None
 
 
     def _deserialize(self, params):
@@ -1140,6 +1255,7 @@ class PullSmsSendStatus(AbstractModel):
         self.SerialNo = params.get("SerialNo")
         self.ReportStatus = params.get("ReportStatus")
         self.Description = params.get("Description")
+        self.SessionContext = params.get("SessionContext")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1275,6 +1391,89 @@ class PullSmsSendStatusResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ReportConversionRequest(AbstractModel):
+    """ReportConversion请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param SmsSdkAppId: 短信应用ID。在 [短信控制台](https://console.cloud.tencent.com/smsv2/app-manage)  添加应用后生成的实际 SdkAppId，示例如1400006666。
+        :type SmsSdkAppId: str
+        :param SerialNo: 发送短信返回的流水号。
+        :type SerialNo: str
+        :param ConversionTime: 用户回填时间，UNIX 时间戳（单位：秒）。
+        :type ConversionTime: int
+        """
+        self.SmsSdkAppId = None
+        self.SerialNo = None
+        self.ConversionTime = None
+
+
+    def _deserialize(self, params):
+        self.SmsSdkAppId = params.get("SmsSdkAppId")
+        self.SerialNo = params.get("SerialNo")
+        self.ConversionTime = params.get("ConversionTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ReportConversionResponse(AbstractModel):
+    """ReportConversion返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ReportConversionStatus: 转化率上报响应包体。
+        :type ReportConversionStatus: :class:`tencentcloud.sms.v20210111.models.ReportConversionStatus`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ReportConversionStatus = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("ReportConversionStatus") is not None:
+            self.ReportConversionStatus = ReportConversionStatus()
+            self.ReportConversionStatus._deserialize(params.get("ReportConversionStatus"))
+        self.RequestId = params.get("RequestId")
+
+
+class ReportConversionStatus(AbstractModel):
+    """转化率上报响应。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Code: 错误码。上报成功返回 ok。
+        :type Code: str
+        :param Message: 错误码描述。
+        :type Message: str
+        """
+        self.Code = None
+        self.Message = None
+
+
+    def _deserialize(self, params):
+        self.Code = params.get("Code")
+        self.Message = params.get("Message")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SendSmsRequest(AbstractModel):
     """SendSms请求参数结构体
 
@@ -1288,20 +1487,20 @@ class SendSmsRequest(AbstractModel):
         :type PhoneNumberSet: list of str
         :param SmsSdkAppId: 短信 SdkAppId，在 [短信控制台](https://console.cloud.tencent.com/smsv2/app-manage)  添加应用后生成的实际 SdkAppId，示例如1400006666。
         :type SmsSdkAppId: str
-        :param TemplateId: 模板 ID，必须填写已审核通过的模板 ID。模板 ID 可登录 [短信控制台](https://console.cloud.tencent.com/smsv2) 查看，若向境外手机号发送短信，仅支持使用国际/港澳台短信模板。
+        :param TemplateId: 模板 ID，必须填写已审核通过的模板 ID。模板 ID 可前往 [国内短信](https://console.cloud.tencent.com/smsv2/csms-template) 或 [国际/港澳台短信](https://console.cloud.tencent.com/smsv2/isms-template) 的正文模板管理查看，若向境外手机号发送短信，仅支持使用国际/港澳台短信模板。
         :type TemplateId: str
-        :param SignName: 短信签名内容，使用 UTF-8 编码，必须填写已审核通过的签名，例如：腾讯云，签名信息可登录 [短信控制台](https://console.cloud.tencent.com/smsv2) 查看。
-<dx-alert infotype="notice" title="注意">国内短信为必填参数。</dx-alert>
+        :param SignName: 短信签名内容，使用 UTF-8 编码，必须填写已审核通过的签名，例如：腾讯云，签名信息可前往 [国内短信](https://console.cloud.tencent.com/smsv2/csms-sign) 或 [国际/港澳台短信](https://console.cloud.tencent.com/smsv2/isms-sign) 的签名管理查看。
+<dx-alert infotype="notice" title="注意">发送国内短信该参数必填。</dx-alert>
         :type SignName: str
         :param TemplateParamSet: 模板参数，若无模板参数，则设置为空。
 <dx-alert infotype="notice" title="注意">模板参数的个数需要与 TemplateId 对应模板的变量个数保持一致。</dx-alert>
         :type TemplateParamSet: list of str
-        :param ExtendCode: 短信码号扩展号，默认未开通，如需开通请联系 [sms helper](https://cloud.tencent.com/document/product/382/3773#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81)。
+        :param ExtendCode: 短信码号扩展号，默认未开通，如需开通请联系 [腾讯云短信小助手](https://cloud.tencent.com/document/product/382/3773#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81)。
         :type ExtendCode: str
         :param SessionContext: 用户的 session 内容，可以携带用户侧 ID 等上下文信息，server 会原样返回。
         :type SessionContext: str
         :param SenderId: 国内短信无需填写该项；国际/港澳台短信已申请独立 SenderId 需要填写该字段，默认使用公共 SenderId，无需填写该字段。
-注：月度使用量达到指定量级可申请独立 SenderId 使用，详情请联系 [sms helper](https://cloud.tencent.com/document/product/382/3773#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81)。
+注：月度使用量达到指定量级可申请独立 SenderId 使用，详情请联系 [腾讯云短信小助手](https://cloud.tencent.com/document/product/382/3773#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81)。
         :type SenderId: str
         """
         self.PhoneNumberSet = None
@@ -1569,7 +1768,7 @@ class SmsPackagesStatisticsRequest(AbstractModel):
 注：拉取套餐包的创建时间不小于起始时间。
         :type BeginTime: str
         :param EndTime: 结束时间，格式为yyyymmddhh，精确到小时，例如2021050118，表示2021年5月1号18时。
-注：EndTime 必须大于 BeginTime，拉取套餐包的创建时间不大于结束时间。
+注：EndTime 必须大于 BeginTime且小于当前时间，拉取套餐包的创建时间不大于结束时间。
         :type EndTime: str
         """
         self.SmsSdkAppId = None
